import pandas as pd
import numpy as np
from PYLIQ_functions import single_plot, Youd_2002, SUMMARY_1, SUMMARY_2, SUMMARY_3
from scipy.optimize import brentq
import matplotlib.pyplot as plt
import warnings
import os
name = "PYLIQ"

def analyze(input_file):
    warnings.filterwarnings("ignore", category=RuntimeWarning)
    file_dir = os.path.dirname(__file__)
    output_dir = os.path.join(file_dir, 'PYLIQ Output/')
    if not os.path.isdir(output_dir):
        os.makedirs(output_dir)

    seed_87_fc = [0, 10, 25, 50, 75]
    seed_87_delta_N160 = [0, 1, 2, 4, 5]
    plt.rc('font', family='arial', size=13)
    plt.rc('legend', fontsize=10)
    plt.rc('xtick', labelsize=11.5)
    plt.rc('xtick.major', size=5)
    plt.rc('ytick', labelsize=11.5)
    plt.rc('ytick.major', size=5)

    depth_all, subdivided_wt, ws_all, LPI_all, LSN_all, LDI_all, LD_Youd_all, Sv1D_all, H1_all, H2_all, \
    fines_susceptibility_all, wc_LL_PI_all = ([] for i in range(12))

    # General input parameters
    Water_unit_weight = 9.81
    Pa = 101.325
    soil_types = ['Sand', 'Gravel', 'Clay', 'Silt', 'Peat', 'Organic', 'Other', np.NaN]

    file = pd.ExcelFile(os.path.join(file_dir, input_file))
    input_df = pd.read_excel(file, 'SUMMARY')
    input_df.set_index('Sheet', inplace=True)
    sheet_list = input_df.index.values.tolist()
    options_df = pd.read_excel(file, 'OPTIONS', header=None, index_col=0)
    anal_depth = options_df.loc['Liquefaction max. depth (m)'].values[0]
    LD_min_thick = options_df.loc['Lateral displacement minimum thickness (m)'].values[0]
    calculate_Youd = options_df.loc['Calculate LD from Youd (2002)'].values[0]
    calculate_fines = options_df.loc['Calculate fines liq. Susceptibility from Bray & Sancio (2006)'].values[0]
    calculate_Sr = options_df.loc['Calculate post-liquefaction residual strength, Sr'].values[0]
    OS_wf = options_df.loc['Weighting factor for Olson & Stark (2002) model'].values[0]
    IB_wf = options_df.loc['Weighting factor for Idriss & Boulanger (2008) model'].values[0]
    W_wf = options_df.loc['Weighting factor for Weber (2015) model'].values[0]
    export_pdf = options_df.loc['Export figures as .PDF'].values[0]
    export_png = options_df.loc['Export figures as .PNG'].values[0]
    export_xlsx = options_df.loc['Export results as .XLSX'].values[0]
    writer = pd.ExcelWriter(output_dir + 'Output.xlsx', engine='openpyxl')

    for ws in sheet_list:
        if input_df.loc[ws, 'run'] != 'YES': continue
        ID = ws
        water_table, Mw, PGA, ER, borehole_diameter, rod_extension, site_condition, slope, H_free_face, L_free_face = \
            input_df.loc[
                ws, ['Water table (m)', 'Mw', 'PGA (g)', 'ER (%)', 'Borehole diameter (mm)', 'Rod extension (m)',
                     'Site condition', 'Ground slope (%)', 'H free face', 'L free face']]
        gen_parameters = 'I&B (2014): Mw = ' + str(Mw) + '; PGA (g) = ' + str(PGA)
        df = pd.read_excel(file, ws)
        rows = df.shape[0]
        water_table_idx = np.searchsorted(df['Depth (m)'], water_table).item()
        soil_type = df['Soil type (USCS)'].str.split('-').str[0].replace(
            {'SM': "Sand", 'SC': "Sand", 'SP': "Sand", 'SW': "Sand", 'GM': "Gravel", 'GC': "Gravel", 'GP': "Gravel",
             'GW': "Gravel", 'CH': "Clay", 'CL': "Clay", 'MH': "Silt", 'ML': "Silt", 'PT': "Peat", 'OH': "Organic",
             'OL': "Organic"})

        soil_type[~soil_type.isin(soil_types)] = 'Other'
        if water_table_idx != 0 and soil_type[water_table_idx] == 'Sand' and df['Depth (m)'][
            water_table_idx] != water_table:
            subdivided_wt.append('YES')
            repeat_array = ([1] * rows)
            repeat_array[water_table_idx] = 2
            soil_type = np.repeat(soil_type, repeat_array).reset_index(drop=True)
            df = pd.DataFrame(np.repeat(df.values, repeat_array, axis=0), columns=df.columns)
            df['Depth (m)'][water_table_idx] = water_table
            rows = df.shape[0]
        else:
            subdivided_wt.append('NO')

        uscs, depth, NSPT, FC_fill, FC_no_fill, unit_weight, D50 = df['Soil type (USCS)'].fillna(''), df[
            'Depth (m)'].astype(float), df.NSPT.astype(float), df['FC (%)'].fillna(method='ffill').fillna(
            method='bfill').astype(float), df['FC (%)'].astype(float), df['Unit weight (kN/m3)'].astype(float), df[
                                                                       'D50 (mm)']
        FC = np.where(soil_type == 'Sand', FC_fill, FC_no_fill)

        depth_max = np.max(depth)
        thickness = np.append(depth[0], np.diff(depth))
        rd = np.clip(np.exp(
            -1.012 - 1.126 * np.sin(depth / 11.73 + 5.133) + Mw * (0.106 + 0.118 * np.sin(depth / 11.28 + 5.142))),
            None, 1)
        total_stress = np.cumsum(thickness * unit_weight)
        effective_stress = total_stress - (np.clip((depth - water_table), 0, None) * Water_unit_weight)
        CSR = 0.65 * PGA * (total_stress / effective_stress) * rd

        Ce = [ER / 60] * rows

        if borehole_diameter < 115.1:
            Cb = 1
        elif borehole_diameter < 150.1:
            Cb = 1.05
        else:
            Cb = 1.15

        Cb = [Cb] * rows

        Cr_bins = np.array([0.75, 0.8, 0.85, 0.95, 1])
        Cr = Cr_bins[np.digitize(depth + rod_extension, [3, 4, 6, 10])]

        Cs = [1] * rows

        flag = (soil_type == 'Sand') & (pd.to_numeric(NSPT, errors='coerce').notnull())
        delta_N160 = np.where(flag, np.exp(1.63 + 9.7 / (FC + 0.01) - (15.7 / (FC + 0.01)) ** 2), np.NaN)

        N60 = NSPT * Ce * Cb * Cr * Cs

        N160CS = []
        for i in range(rows):
            if flag[i]:
                def f(N160CS):
                    return (np.clip(
                        (Pa / effective_stress[i]) ** (0.784 - 0.0768 * np.sqrt(np.clip(N160CS, 1, 46))), None,
                        1.7) - (
                                    N160CS - delta_N160[i]) / N60[i])

                N160CS.append(brentq(f, 1, 200))
            else:
                N160CS.append(np.NaN)
        N160CS = np.asarray(N160CS)
        N160 = N160CS - delta_N160
        Cn = N160 / N60

        MSF = 1 + ((np.clip(1.09 + (N160CS / 31.5) ** 2, None, 2.2) - 1) * (8.64 * np.exp(-Mw / 4) - 1.325))
        K_sigma = np.clip(
            1 - (1 / (18.9 - 2.55 * np.sqrt(np.clip(N160CS, None, 37))) * np.log(effective_stress / Pa)),
            None,
            1.1)
        K_alpha = 1
        flag_FS = (flag & (depth > water_table) & (depth <= anal_depth) & (N160CS < 37.5))
        CRR_75 = np.where(flag_FS,
                          np.exp(N160CS / 14.1 + (N160CS / 126) ** 2 - (N160CS / 23.6) ** 3 + (
                                  N160CS / 25.4) ** 4 - 2.8),
                          2)
        CRR = np.clip(CRR_75 * K_sigma * K_alpha * MSF, None, 2)
        CRR = np.where(np.isnan(CRR), 2, CRR)

        FS_liq = np.clip(CRR / CSR, None, 2)
        mid_depth = depth - thickness / 2
        gamma_lim = np.clip(1.859 * (1.1 - np.sqrt(N160CS / 46)) ** 3, 0, 0.5)
        gamma_lim = np.where(np.isnan(gamma_lim), 0, gamma_lim)
        F_alpha = 0.032 + 0.69 * np.sqrt(np.clip(N160CS, 7, None)) - 0.13 * np.clip(N160CS, 7, None)
        F_alpha = np.where(np.isnan(F_alpha), 0, F_alpha)
        gamma_max = np.where(FS_liq > 2, 0,
                             np.where(FS_liq < F_alpha, gamma_lim,
                                      np.clip(gamma_lim, None,
                                              0.035 * (1 - F_alpha) * (2 - FS_liq) / (FS_liq - F_alpha))))
        xi_v = 1.5 * np.exp(-0.369 * np.sqrt(N160CS)) * np.clip(gamma_max, None, 0.08)
        xi_v = np.where(np.isnan(xi_v), 0, xi_v)
        contiguous_soil_type_thickness = pd.DataFrame(thickness).groupby(
            (soil_type != soil_type.shift()).cumsum()).transform('sum')[0]
        LDIi = gamma_max * thickness
        LDIi[contiguous_soil_type_thickness < LD_min_thick] = 0
        LDI = np.cumsum(LDIi[::-1])[::-1]
        Sv1Di = xi_v * thickness
        Sv1D = np.cumsum(Sv1Di[::-1])[::-1]
        LSNi = 1000 * (xi_v / mid_depth) * thickness
        LSNi = np.where(np.isnan(LSNi), 0, LSNi)
        LSN = np.cumsum(LSNi[::-1])[::-1]
        LPIi = np.where(FS_liq < 1, 1 - FS_liq, 0) * np.where(mid_depth <= 20, 10 - 0.5 * mid_depth, 0) * thickness
        LPI = np.cumsum(LPIi[::-1])[::-1]
        a = next((i for i, v in enumerate(FS_liq) if v < 1), rows - 1)
        H1 = depth[a - 1] if a > 0 else 0
        H2 = np.clip(thickness[FS_liq < 1].sum(), None, 9)

        if calculate_Youd == 'YES':
            R = options_df.loc['R (km) [for Youd (2002) only]'].values[0]
            flag_T15 = (flag & (depth > water_table) & (depth <= anal_depth) & (N160 < 15) & (
                    contiguous_soil_type_thickness > LD_min_thick))
            DH = Youd_2002(site_condition, thickness, flag_T15, FC, D50, slope, Mw, R, H_free_face, L_free_face)
            LD_Youd = LDI * (DH / np.max(LDI))
        else:
            DH = np.NaN
            LD_Youd = ([np.NaN] * rows)
        if export_pdf in ['Borings+SUMMARY', 'Borings'] or export_png in ['Borings+SUMMARY', 'Borings']:
            lyr_subdivision = options_df.loc['Plot soil column layer subdivisions'].values[0]
            single_plot(NSPT, N160, FC, FC_no_fill, CSR, CRR, FS_liq, LPI, LDI, Sv1D, LSN, gamma_max, xi_v, depth,
                        mid_depth, thickness, soil_type, soil_types, uscs, water_table, lyr_subdivision, ID, output_dir,
                        export_pdf, export_png, gen_parameters)
        if calculate_Sr == 'YES':
            Sr_OS_2002 = np.where(FS_liq < 1, effective_stress * (0.03 + 0.0075 * np.clip(N160, None, 20)), np.NaN)
            Sr_Weber_2015 = np.where(FS_liq < 1, np.clip(
                6 / 125 * (np.exp(0.1407 * N160CS + 4.2399 * (effective_stress / Pa) ** 0.120) - 0.43991 * (
                        N160CS ** 1.45 + 0.2 * N160CS * (effective_stress / Pa) ** 2.48 + 41.13)), None,
                0.29 * effective_stress), np.NaN)
            delta_seed = [seed_87_delta_N160[i] for i in np.searchsorted(seed_87_fc, FC_fill + 0.01) - 1]
            N160CS_seed_87 = N160 + delta_seed
            Sr_IB_2008_void_red = np.where(FS_liq < 1, effective_stress * np.exp(
                N160CS_seed_87 / 16 + ((N160CS_seed_87 - 16) / 21.2) ** 3 - 3), np.NaN)
            Sr_weighted = OS_wf * Sr_OS_2002 + IB_wf * Sr_IB_2008_void_red + W_wf * Sr_Weber_2015
        else:
            Sr_OS_2002 = pd.Series([np.NaN] * rows)
            Sr_Weber_2015 = pd.Series([np.NaN] * rows)
            Sr_IB_2008_void_red = pd.Series([np.NaN] * rows)
            Sr_weighted = pd.Series([np.NaN] * rows)
        if calculate_fines == 'YES':
            PI = df['PI']
            wc_LL = df['wc'] / df['LL']
            fines_susceptibility = np.where((PI <= 12) & (wc_LL > 0.85), 'Susceptible',
                                            np.where((PI <= 18) & (wc_LL > 0.8), 'Moderate', None))
            wc_LL_PI_all.append([wc_LL.tolist(), PI.tolist()])
            if 'Moderate' in fines_susceptibility and 'Susceptible' not in fines_susceptibility:
                fines_susceptibility_all.append('Moderate')
            elif 'Susceptible' in fines_susceptibility:
                fines_susceptibility_all.append('Susceptible')
            else:
                fines_susceptibility_all.append('Non')
        else:
            fines_susceptibility = pd.Series(None)
            fines_susceptibility_all.append(None)
        print(ID + ' successful')
        depth_all.append(depth_max)
        ws_all.append(ws)
        LPI_all.append(np.max(LPI))
        LSN_all.append(np.max(LSN))
        LDI_all.append(np.max(LDI))
        LD_Youd_all.append(DH)
        Sv1D_all.append(np.max(Sv1D))
        H1_all.append(H1)
        H2_all.append(H2)

        if export_xlsx == 'YES':
            df2 = pd.DataFrame(
                data=(
                    [soil_type, total_stress, effective_stress, Cn, Cr, pd.Series(Cb), pd.Series(Cs), pd.Series(Ce),
                     N60,
                     N160,
                     delta_N160,
                     N160CS, rd, MSF, CSR, CRR,
                     FS_liq, LPI, gamma_lim, F_alpha, gamma_max, xi_v, LDI, LD_Youd, Sv1D, LSN, fines_susceptibility,
                     Sr_OS_2002, Sr_IB_2008_void_red, Sr_Weber_2015, Sr_weighted])).T
            df2.columns = ['Soil type', 'Total stress (kPa)', 'Effective stress (kPa)', 'Cn', 'Cr', 'Cb', 'Cs', 'Ce',
                           'N60',
                           'N160',
                           'Δ_N160', 'N160CS', 'rd', 'MSF', 'CSR', 'CRR', 'FS_liq', 'LPI', 'γ_lim', 'F_α',
                           'γ_max', 'ξ_v', 'LDI (m)', 'LD (m) Youd (2002)', 'Sv-1D (m)', 'LSN', 'Fines susceptibility',
                           'Sr (kPa) Olson & Stark (2002)', 'Sr (kPa) Idriss & Boulanger (2008)',
                           'Sr (kPa) Weber (2015)', 'Sr (kPa)']
            df = df.join([df2])
            df.to_excel(writer, index=False, sheet_name=ws, float_format='%0.3f')

    if export_pdf in ['Borings+SUMMARY', 'SUMMARY'] or export_png in ['Borings+SUMMARY', 'SUMMARY']:
        SUMMARY_1(LPI_all, LSN_all, LDI_all, LD_Youd_all, Sv1D_all, ws_all, calculate_Youd, LD_min_thick, output_dir,
                  export_pdf, export_png, gen_parameters)
        SUMMARY_2(H1_all, H2_all, ws_all, output_dir, export_pdf, export_png, gen_parameters)
        if calculate_fines == 'YES':
            SUMMARY_3(wc_LL_PI_all, ws_all, output_dir, export_pdf, export_png)

    if export_xlsx == 'YES':
        LPI_ranges = [0, 5, 15]
        LPI_labels = ['Low', 'Moderate', 'High']
        LSN_ranges = [0, 10, 20, 30, 40, 50]
        LSN_labels = ['Little to non', 'Minor', 'Moderate', 'Moderate to severe', 'Mayor', 'Severe damage']
        LPI_results_labels = [LPI_labels[i] for i in np.searchsorted(LPI_ranges, LPI_all) - 1]
        LSN_results_labels = [LSN_labels[i] for i in np.searchsorted(LSN_ranges, LSN_all) - 1]
        df2 = pd.DataFrame(data=(
            [depth_all, subdivided_wt, LPI_all, LPI_results_labels, LSN_all, LSN_results_labels, LDI_all, LD_Youd_all,
             Sv1D_all,
             H1_all, H2_all, fines_susceptibility_all])).T
        df2.columns = ['Total depth (m)', 'Subdivided @water_table', 'LPI', 'LPI label', 'LSN', 'LSN label', 'LDI (m)',
                       'LD (m) Youd (2002)',
                       'Sv-1D (m)', 'H1 (m)', 'H2 (m)', 'Fines susceptibility']
        df = input_df[input_df['run'] == 'YES'].reset_index().join([df2])
        df.to_excel(writer, index=False, sheet_name='SUMMARY', float_format='%0.3f')
        writer.save()

    input('Press ENTER to exit')



import matplotlib.pyplot as plt
import numpy as np
import itertools
import pandas as pd
from matplotlib.ticker import AutoMinorLocator
from math import log10


def single_plot(NSPT, N160, FC, FC_no_fill, CSR, CRR, FS_liq, LPI, LDI, Sv1D, LSN, gamma_max, xi_v, depth,
                mid_depth, thickness, soil_type, soil_types, uscs, water_table, lyr_subdivision, ID, output_dir,
                export_pdf, export_png, gen_parameters):
    depth_max_rounded = np.ceil(np.max(depth))
    hatches = ['...', '', '//', '|', '|', '///', '', '']
    colors = ('white', 'orange', 'white', 'white', 'white', 'white', 'white', 'white')
    edgecolors = ('grey', 'black', 'green', 'orange', 'black', 'black', 'black', 'black')
    primary_x_vars = [[NSPT, N160], [FC, FC_no_fill], [CSR, CRR], [FS_liq], [LPI], [LDI], [Sv1D]]
    primary_x_vars_labels = [['NSPT', 'N160'], ['FC filled', 'FC'], ['CSR', 'CRR'], ['FS_liq'], ['LPI'], ['LDI'],
                             ['Sv1D']]
    primary_x_vars_styles = [['ko-', 'bo'], ['bo', 'ko'], ['k-', 'ko-'], ['ko-'], ['ko-'], ['ko-'], ['ko-']]
    primary_x_labels = ['Blow count', 'Fines content (%)', 'CSR & CRR', 'FS Liq', 'LPI', 'LDI (m)', 'Sv-1D (m)']
    primary_y_vars = [depth, depth, depth, depth, mid_depth, mid_depth, mid_depth]
    secondary_x_vars = [None, None, None, None, LSN, gamma_max, xi_v, None]
    secondary_x_vars_labels = [None, None, None, None, 'LSN', 'γ max', 'ξv', None]
    contiguous_soil_type = soil_type.groupby(
        (uscs != uscs.shift()).cumsum()).first()
    contiguous_uscs = uscs.groupby(
        (uscs != uscs.shift()).cumsum()).first()
    contiguous_uscs_thickness = pd.DataFrame(thickness).groupby(
        (uscs != uscs.shift()).cumsum())[0].sum()
    fig, axes = plt.subplots(1, 8, sharey=True)
    for i, ax in enumerate(axes.flat):
        if i < 7:
            for j, var in enumerate(primary_x_vars[i]):
                ax.plot(var, primary_y_vars[i], primary_x_vars_styles[i][j], label=primary_x_vars_labels[i][j])
            ax.legend() if i < 3 else None
            ax.set_xlim(left=0)
            ax.set(xlabel=primary_x_labels[i])
            ax.xaxis.set_minor_locator(AutoMinorLocator())
        else:
            soil_type_indices = [soil_types.index(i) for i in contiguous_soil_type]
            hatch = [hatches[i] for i in soil_type_indices]
            color = [colors[i] for i in soil_type_indices]
            edgecolor = [edgecolors[i] for i in soil_type_indices]
            bottom = np.append(0, np.cumsum(contiguous_uscs_thickness)[:-1])
            patches = ax.bar(1, contiguous_uscs_thickness, bottom=bottom, color=color,
                             lw=(0 if lyr_subdivision == 'NO' else 1),
                             edgecolor=edgecolor)
            for patch_set, hatch in zip(patches, hatch):
                plt.setp(patch_set, hatch=hatch)
            cut_z = 0
            for ri, r in enumerate(patches):
                cut_z = cut_z + contiguous_uscs_thickness[ri + 1]
                cut_z_mid = cut_z - contiguous_uscs_thickness[ri + 1] / 2
                ax.text(r.get_x() + r.get_width() / 2, cut_z_mid, str(contiguous_uscs[ri + 1]), ha="center",
                        va="center", color="black", fontsize=10, fontweight='bold')
        if secondary_x_vars[i] is not None:
            ax_secondary = ax.twiny()
            ax_secondary.plot(secondary_x_vars[i], primary_y_vars[i], 'o-', color='grey',
                              label=secondary_x_vars_labels[i])
            ax_secondary.set_xlabel(secondary_x_vars_labels[i], color='grey')
            ax_secondary.tick_params(axis='x', which='both', colors='grey')
            ax_secondary.xaxis.set(label_position='bottom', ticks_position='bottom')
            ax_secondary.set_xlim(left=0)
            ax_secondary.xaxis.set_minor_locator(AutoMinorLocator())
        ax.xaxis.tick_top()
        ax.xaxis.set_label_position('top')
    axes[0].yaxis.set_minor_locator(AutoMinorLocator())
    axes[0].set(ylabel='Depth (m)')
    axes[3].axvline(x=1, color='r')
    axes[7].set(title='Soil column', xticks=[])
    axes[7].axhline(y=water_table, color='b')
    axes[7].spines['top'].set_visible(False)
    axes[7].spines['right'].set_visible(True)
    axes[7].spines['bottom'].set_visible(False)
    axes[7].tick_params(axis='y', which='both', labelright=True, right=True)
    plt.ylim(bottom=0, top=depth_max_rounded)
    axes[0].invert_yaxis()
    fig.set_size_inches(16, 10)
    plt.suptitle('Soil liquefaction analysis from SPT ' + ID, fontsize=14)
    fig.text(0.1, 0.965, gen_parameters, color='blue', fontsize=12)
    fig.text(1, 0, 'PYLIQ', color='grey', fontsize=12)
    plt.subplots_adjust(left=None, bottom=0.03, right=1, top=0.9, wspace=0.1, hspace=None)
    if export_pdf in ['Borings+SUMMARY', 'Borings']: plt.savefig(output_dir + ID + '.pdf',
                                                                 format='pdf', dpi=900,
                                                                 bbox_inches='tight')
    if export_png in ['Borings+SUMMARY', 'Borings']: plt.savefig(output_dir + ID + '.png',
                                                                 format='png', bbox_inches='tight')
    plt.close()


def Youd_2002(site_condition, thickness, flag_T15, FC, D50, slope, Mw, R, H_free_face, L_free_face):
    if site_condition == 'Level ground':
        DH = 0
    else:
        T15 = thickness[flag_T15].sum()
        if T15 != 0:
            F15 = FC[flag_T15].mean()
            D50_filled = D50.fillna(method='ffill').fillna(method='bfill')
            D5015 = D50_filled[flag_T15].mean()
            if site_condition == 'Sloping ground':
                if 0.1 <= slope <= 6:
                    DH = 10 ** (-16.213 + 1.532 * Mw - 1.406 * log10(
                        10 ** (0.89 * Mw - 5.64) + R) - 0.012 * R + 0.338 * log10(
                        slope) + 0.54 * log10(T15) + 3.413 * log10(100 - F15) - 0.795 * log10(D5015 + 0.1))
                else:
                    print(ID + ' Youd (2002): Ground slope must be between 0.1 to 6 %')
                    DH = np.NaN
            if site_condition == 'Free face':
                if 1 <= 100 * (H_free_face / L_free_face) <= 20:
                    DH = 10 ** (-16.713 + 1.532 * Mw - 1.406 * log10(
                        10 ** (0.89 * Mw - 5.64) + R) - 0.012 * R + 0.592 * log10(
                        100 * (H_free_face / L_free_face)) + 0.54 * log10(T15) + 3.413 * log10(
                        100 - F15) - 0.795 * log10(
                        D5015 + 0.1))
                else:
                    print(ID + ' Youd (2002): Free face ratio (H/L) must be between 1 to 20 %')
                    DH = np.NaN
        else:
            DH = 0
    return DH


def SUMMARY_1(LPI_all, LSN_all, LDI_all, LD_Youd_all, Sv1D_all, ws_all, calculate_Youd, LD_min_thick, output_dir,
              export_pdf, export_png, gen_parameters):
    LPI_ranges = [0, 5, 15]
    LPI_colors = ['yellow', 'orange', 'red']
    LPI_labels = ['Low', 'Moderate', 'High']
    LSN_ranges = [0, 10, 20, 30, 40, 50]
    LSN_colors = ['slateblue', 'blue', 'gold', 'yellow', 'orange', 'red']
    LSN_labels = ['Little to non', 'Minor', 'Moderate', 'Moderate to severe', 'Mayor', 'Severe damage']
    fig, ax = plt.subplots(2, 2)
    fig.set_size_inches(16, 10)
    fig.text(0.97, 0.96, 'PYLIQ', color='grey', fontsize=12)
    fig.text(0.1, 0.965, gen_parameters, color='blue', fontsize=12)
    fig.suptitle('Soil liquefaction analysis from SPT SUMMARY')
    primary_y_vars = [LPI_all, LSN_all]
    ranges = [LPI_ranges, LSN_ranges]
    labels = [LPI_labels, LSN_labels]
    colors = [LPI_colors, LSN_colors]
    titles = ['LPI from Iwasaki et al. (1978)', 'LSN from van Ballegooy et al. (2014)']
    for i, var in enumerate(primary_y_vars):
        ax[0, i].bar(ws_all, var, color='black', zorder=2)
        ax[0, i].set(title=titles[i])
        bottom, top = ax[0, i].get_ylim()
        ranges[i].append(top)
        for j, label in enumerate(labels[i]):
            ax[0, i].axhspan(ranges[i][j], ranges[i][j + 1], color=colors[i][j], zorder=1, label=label)
        ax[0, i].set(ylim=[0, top])
        ax[0, i].legend()
    bar_width = 0.35
    ws_all_indices = np.arange(len(ws_all))
    if calculate_Youd == 'YES':
        ax[1, 0].bar(ws_all_indices - bar_width / 2, LDI_all, bar_width, color='black', label='LDI I&B (2014)')
        ax[1, 0].bar(ws_all_indices + bar_width / 2, LD_Youd_all, bar_width, color='red', label='LD Youd (2002)')
    else:
        ax[1, 0].bar(ws_all_indices, LDI_all, color='black', label='LDI I&B (2014)')
    ax[1, 0].set_xticks(ws_all_indices)
    ax[1, 0].legend()
    ax[1, 0].set(title='LD (m), minimum thickness considered (m): ' + str(LD_min_thick))
    ax[1, 1].bar(ws_all, Sv1D_all, color='black')
    ax[1, 1].set(title='Sv-1D (m)')
    plt.subplots_adjust(left=None, bottom=0.11, right=1, top=0.92, wspace=0.1, hspace=0.25)
    for i, axi in enumerate(ax.flat):
        axi.set_xticklabels(ws_all, rotation=30, ha='right')
    if export_pdf in ['Borings+SUMMARY', 'SUMMARY']: plt.savefig(output_dir + 'SUMMARY_1.pdf',
                                                                 format='pdf', dpi=900,
                                                                 bbox_inches='tight')
    if export_png in ['Borings+SUMMARY', 'SUMMARY']: plt.savefig(output_dir + 'SUMMARY_1.png',
                                                                 format='png', bbox_inches='tight')
    plt.close()


def SUMMARY_2(H1_all, H2_all, ws_all, output_dir, export_pdf, export_png, gen_parameters):
    fig, ax = plt.subplots(1, 1)
    fig.set_size_inches(16, 10)
    fig.text(0.87, 0.065, 'PYLIQ', color='grey', fontsize=12)
    fig.text(0.1, 0.89, gen_parameters, color='blue', fontsize=12)
    plt.title('Site identification of liquefaction-induced damage from Ishihara (1985)')
    H1_200gal = [0.833, 1.077, 1.313, 1.6, 1.881, 2.213, 2.449, 2.59, 2.738, 2.908, 2.983, 3., 3.]
    H2_200gal = [0.781, 1.022, 1.263, 1.572, 1.871, 2.276, 2.605, 2.856, 3.146, 3.563, 3.951, 4.212, 8.009]
    H1_300gal = [1.245, 1.776, 2.218, 2.814, 3.537, 4.111, 4.789, 5.158, 5.306, 5.498, 5.72, 5.883, 5.994,
                 6.091,
                 6.159,
                 6.219, 6.25, 6.287, 6.318]
    H2_300gal = [0.826, 1.172, 1.461, 1.845, 2.325, 2.72, 3.259, 3.615, 3.789, 4.079, 4.485, 4.911, 5.338,
                 5.832,
                 6.269,
                 6.715, 7.084, 7.433, 7.928]
    H1_400_500gal = [1.09, 0.994, 1.237, 1.436, 1.737, 2.179, 2.68, 3.003, 3.563, 4.078, 4.91, 5.536, 6.169,
                     6.949,
                     7.244,
                     7.583, 7.834, 8.085, 8.292, 8.477, 8.662, 8.825, 8.989, 9.145, 9.272]
    H2_400_500gal = [0.42, 0.382, 0.477, 0.553, 0.658, 0.83, 1.021, 1.135, 1.354, 1.545, 1.879, 2.079, 2.269,
                     2.574,
                     2.727,
                     3.007, 3.306, 3.654, 4.002, 4.428, 4.912, 5.377, 5.919, 6.52, 7.053]
    ax.plot(H1_200gal, H2_200gal, 'k', label='amax≈0.2g')
    ax.plot(H1_300gal, H2_300gal, 'k--', label='amax≈0.3g')
    ax.plot(H1_400_500gal, H2_400_500gal, 'k-.', label='amax≈0.4g-0.5g')
    ax.scatter(H1_all, H2_all, label='borings')
    for i, txt in enumerate(ws_all):
        ann = ax.annotate(' ' + txt, (H1_all[i], H2_all[i]))
        ann.set_clip_box(ax.bbox)
    ax.set(xlabel='Thickness of surface layer, H1 (m)', ylabel='Thickness of liquefiable sand layer, H2 (m)')
    ax.legend()
    plt.xlim(plt.xlim()[0], 10)
    if export_pdf in ['Borings+SUMMARY', 'SUMMARY']: fig.savefig(output_dir + 'SUMMARY_2.pdf',
                                                                 format='pdf', dpi=900,
                                                                 bbox_inches='tight')
    if export_png in ['Borings+SUMMARY', 'SUMMARY']: fig.savefig(output_dir + 'SUMMARY_2.png',
                                                                 format='png', bbox_inches='tight')
    plt.close()


def SUMMARY_3(wc_LL_PI_all, ws_all, output_dir, export_pdf, export_png):
    markers = itertools.cycle(('o', 's', '^', 'D'))
    fig, ax = plt.subplots(1, 1)
    fig.set_size_inches(16, 10)
    fig.text(0.87, 0.065, 'PYLIQ', color='grey', fontsize=12)
    plt.title('Assessment of the Liquefaction Susceptibility of Fine-Grained Soils from Bray & Sancio (2006)')
    for i, wc_LL_PI in enumerate(wc_LL_PI_all):
        ax.plot(*wc_LL_PI, marker=next(itertools.cycle(markers)), linestyle='None', label=ws_all[i])
    plt.xlim(left=0.4, right=1.6)
    plt.ylim(bottom=0, top=60)
    plt.plot([0.8, 0.8, 1.6], [0, 18, 18], 'k', lw=1.0)
    plt.text(1.2, 9, 'Susceptible', ha='center')
    plt.plot([0.85, 0.85, 1.6], [0, 12, 12], 'k', lw=1.0)
    plt.text(1.2, 15, 'Mod. susceptible', ha='center')
    plt.text(0.5, 45, 'Not susceptible', ha='center')
    plt.ylabel('Plasticity index, PI')
    plt.xlabel('water content / Liquid Limit, wc/LL')
    ax.legend()
    if export_pdf in ['Borings+SUMMARY', 'SUMMARY']: fig.savefig(output_dir + 'SUMMARY_3.pdf',
                                                                 format='pdf', dpi=900,
                                                                 bbox_inches='tight')
    if export_png in ['Borings+SUMMARY', 'SUMMARY']: fig.savefig(output_dir + 'SUMMARY_3.png',
                                                                 format='png', bbox_inches='tight')
    plt.close()



from setuptools import setup

setup(
    name='PYLIQ',
    version='1.0.0',
    description='Free soil liquefaction analysis software from SPT data',
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    include_package_data=True,
    author='Jorge Ordóñez',
    author_email='jorgeordonezr@gmail.com',
    url='https://github.com/jorge243/PYLIQ',
    packages=['PYLIQ'],
    license=['MIT'],
)